@@ -1,8 +1,8 @@
-#! /usr/bin/python
+#! /usr/bin/env python
 # vim: tabstop=8 shiftwidth=8 expandtab
-# $Id: setupmingw32.py,v 1.11 2019/05/02 17:30:20 nanard Exp $
-# the MiniUPnP Project (c) 2007-2014 Thomas Bernard
-# http://miniupnp.tuxfamily.org/ or http://miniupnp.free.fr/
+# $Id: setupmingw32.py,v 1.13 2020/10/15 22:27:08 nanard Exp $
+# the MiniUPnP Project (c) 2007-2020 Thomas Bernard
+# https://miniupnp.tuxfamily.org/ or http://miniupnp.free.fr/
 #
 # python script to build the miniupnpc module under windows (using mingw32)
 #
@@ -30,6 +30,6 @@ setup(name="miniupnpc",
       ext_modules=[
          Extension(name="miniupnpc", sources=["miniupnpcmodule.c"],
                    libraries=["ws2_32", "iphlpapi"] + compat_lib,
-                   extra_objects=["libminiupnpc.a"])
+                   extra_objects=["miniupnpc.lib"])
       ])
 
